#!/bin/bash

# Syntax: run_basic_tests.bash [options] <ORAC> 
#  where <ORAC> is the full name of the program 
#   options: -z -> clear temp files and exit
#            -h -> display this help

# ORAC program: Do all SMD tests sequentially 
# script has been tested on Linux platforms only. 

# ----------------------------------------------------------------------
# Help: copy first comments block in this file
# ----------------------------------------------------------------------
function Help {
name=`basename "$0"`;
sed -n "s/\$0/$name/;2,/^\$/p" $0; exit
}


# ----------------------------------------------------------------------
# other functions
# ----------------------------------------------------------------------
function CleanUpFiles {
    rm -rf $* >& /dev/null
}

# ----------------------------------------------------------------------
# init and defaults   
# ----------------------------------------------------------------------
TEMP_FILES="\
  *.out \
  *.pdb \
  *.prmtpg \
  *.rst \
  tmp* \
  *.vor \
  tt.* \
  *.frq \
  solution* \
  *_file \
  6.* \
  *.dump \
"


# ----------------------------------------------------------------------
# command line options
# ----------------------------------------------------------------------
while getopts "hz" Option
do
  case $Option in
    h     )    Help;;    # help: copy first comments block
    z     )    CleanUpFiles $TEMP_FILES; exit ;;  # just cleanup
    *     )    Help;;
  esac
done

shift $(($OPTIND - 1))
#  Decrements the argument pointer so it points to next argument.
#  $1 now references the first non option item supplied on the command line
#+ if one exists.

# ----------------------------------------------------------------------
# command line arguments
# ----------------------------------------------------------------------
if [ $# -lt 1 ] ; then
    Help;
    exit
else 
    ORAC=$1
fi


# ----------------------------------------------------------------------
# initial checks and cleanup
# ----------------------------------------------------------------------

#
# make sure all needed programs are executable and on the $PATH
#
###BINARIES="mpiexec mpdallexit mpdboot $ORAC"
BINARIES="$ORAC"

for prog in $BINARIES; do
    if ! type $prog >/dev/null 2>&1; then
	echo "ERROR: \"$prog\" not found."
	echo "       This is needed by $0 to work. Check your"
	echo "       \$PATH variable or install program \"$prog\"."
	exit 2
    fi
done


#
# files cleanup
#
CleanUpFiles $TEMP_FILES;


# ----------------------------------------------------------------------
#   TESTS
# ----------------------------------------------------------------------



IN="0  1  2  3  4  5"

echo "Running tests $IN ..."
printf "" > OUT_TEST
for i in $IN ; do 
    echo "Testing ${i}.in..." >> OUT_TEST;
    time $ORAC < ${i}.in | grep "Total    = " >> OUT_TEST ;
    printf "... test n.$i done  \n\n"; 
done

# Now check if tests are OK (or almost OK) 
diff OUT_TEST OUT >& tmp.diff;

echo "** TEST COMPLETED **"

if `test -s tmp.diff`; 
then 
    echo "-------------------------------------------------------------------"
    echo " Warning - your output differs from reference:" 
    echo " compare OUT_TEST to reference OUT (try \`make diff'), "
    echo " or you may want to run individual tests with e.g. \`make 2b.out'"
    echo ""
    echo " Please be aware that compiler and machine peculiarities may"
    echo " lead to (energy) differences of order .1 or less"
    echo "-------------------------------------------------------------------"
    exit  
else
    echo "** TEST SUCCESSFUL **"
fi

exit


